from .proto import notification_hub_pb2 as pb


class MessageType:
    MARKETING = 0
    TRANSACTIONAL = 1
    OTP = 2


class WaterfallMode:
    AUTO = 0
    OVERRIDE = 1


class Platform:
    Aasaanjobs = 1
    OLXPeople = 2


class ClientPlatform:
    ANDROID = 0
    IOS = 1
    WEB = 2


class Waterfall:
    """
    Initiates Waterfall object
    The priority of the channel in the task
    The time offset in seconds after which the notification should be triggered after the previous channel
    """

    def __init__(self, priority: int = 0, offset_time: int = 0):
        self._waterfall = pb.Waterfall()
        self._waterfall.priority = priority
        self._waterfall.offsetTime = offset_time

    @property
    def proto(self) -> pb.Waterfall:
        return self._waterfall



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: notificationHub.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='notificationHub.proto',
  package='notification_hub',
  syntax='proto3',
  serialized_options=b'Z\002pb',
  serialized_pb=b'\n\x15notificationHub.proto\x12\x10notification_hub\"\xef\x04\n\x10NotificationTask\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x43\n\x0bmessageType\x18\x03 \x01(\x0e\x32..notification_hub.NotificationTask.MessageType\x12&\n\x05\x65mail\x18\x04 \x01(\x0b\x32\x17.notification_hub.Email\x12\"\n\x03sms\x18\x05 \x01(\x0b\x32\x15.notification_hub.SMS\x12,\n\x08whatsapp\x18\x06 \x01(\x0b\x32\x1a.notification_hub.Whatsapp\x12$\n\x04push\x18\x07 \x01(\x0b\x32\x16.notification_hub.Push\x12\x10\n\x08sentByID\x18\x08 \x01(\t\x12\x0e\n\x06\x63lient\x18\t \x01(\t\x12G\n\rwaterfallType\x18\n \x01(\x0e\x32\x30.notification_hub.NotificationTask.WaterfallMode\x12\x13\n\x0btriggeredOn\x18\x0b \x01(\x03\x12=\n\x08platform\x18\x0c \x01(\x0e\x32+.notification_hub.NotificationTask.Platform\x12\x0f\n\x07\x65ventID\x18\r \x01(\t\"8\n\x0bMessageType\x12\r\n\tMARKETING\x10\x00\x12\x11\n\rTRANSACTIONAL\x10\x01\x12\x07\n\x03OTP\x10\x02\"\'\n\rWaterfallMode\x12\x08\n\x04\x41UTO\x10\x00\x12\x0c\n\x08OVERRIDE\x10\x01\")\n\x08Platform\x12\x0e\n\nAASAANJOBS\x10\x00\x12\r\n\tOLXPEOPLE\x10\x01\"1\n\tWaterfall\x12\x10\n\x08priority\x18\x01 \x01(\x05\x12\x12\n\noffsetTime\x18\x02 \x01(\x05\"\x8e\x01\n\x03SMS\x12\x10\n\x08template\x18\x01 \x01(\t\x12\x0e\n\x06mobile\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontext\x18\x03 \x01(\t\x12\x34\n\x0fwaterfallConfig\x18\x04 \x01(\x0b\x32\x1b.notification_hub.Waterfall\x12\x0e\n\x06\x65xpiry\x18\x05 \x01(\x03\x12\x0e\n\x06userID\x18\x06 \x01(\t\"\x93\x01\n\x08Whatsapp\x12\x10\n\x08template\x18\x01 \x01(\t\x12\x0e\n\x06mobile\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontext\x18\x03 \x01(\t\x12\x34\n\x0fwaterfallConfig\x18\x04 \x01(\x0b\x32\x1b.notification_hub.Waterfall\x12\x0e\n\x06\x65xpiry\x18\x05 \x01(\x03\x12\x0e\n\x06userID\x18\x06 \x01(\t\"=\n\x0e\x45mailRecipient\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06userID\x18\x03 \x01(\t\"0\n\x0f\x45mailAttachment\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"\x8e\x03\n\x05\x45mail\x12\x10\n\x08template\x18\x01 \x01(\t\x12\x36\n\x0ctoRecipients\x18\x02 \x03(\x0b\x32 .notification_hub.EmailRecipient\x12\x0f\n\x07\x63ontext\x18\x03 \x01(\t\x12\x0f\n\x07subject\x18\x04 \x01(\t\x12\x30\n\x06sender\x18\x05 \x01(\x0b\x32 .notification_hub.EmailRecipient\x12\x31\n\x07replyTo\x18\x06 \x01(\x0b\x32 .notification_hub.EmailRecipient\x12\x36\n\x0c\x63\x63Recipients\x18\x07 \x03(\x0b\x32 .notification_hub.EmailRecipient\x12\x36\n\x0b\x61ttachments\x18\x08 \x03(\x0b\x32!.notification_hub.EmailAttachment\x12\x34\n\x0fwaterfallConfig\x18\t \x01(\x0b\x32\x1b.notification_hub.Waterfall\x12\x0e\n\x06\x65xpiry\x18\n \x01(\x03\"\xa4\x02\n\x04Push\x12\x10\n\x08template\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontext\x18\x03 \x01(\t\x12\x34\n\x0fwaterfallConfig\x18\x04 \x01(\x0b\x32\x1b.notification_hub.Waterfall\x12\x0e\n\x06\x65xpiry\x18\x05 \x01(\x03\x12\x0e\n\x06userID\x18\x06 \x01(\t\x12\x14\n\x0c\x65xtraPayload\x18\x07 \x01(\t\x12=\n\x0e\x63lientPlatform\x18\x08 \x01(\x0e\x32%.notification_hub.Push.ClientPlatform\x12\x0e\n\x06\x64ryRun\x18\t \x01(\x08\"/\n\x0e\x43lientPlatform\x12\x0b\n\x07\x41NDROID\x10\x00\x12\x07\n\x03IOS\x10\x01\x12\x07\n\x03WEB\x10\x02\x42\x04Z\x02pbb\x06proto3'
)



_NOTIFICATIONTASK_MESSAGETYPE = _descriptor.EnumDescriptor(
  name='MessageType',
  full_name='notification_hub.NotificationTask.MessageType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MARKETING', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRANSACTIONAL', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OTP', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=527,
  serialized_end=583,
)
_sym_db.RegisterEnumDescriptor(_NOTIFICATIONTASK_MESSAGETYPE)

_NOTIFICATIONTASK_WATERFALLMODE = _descriptor.EnumDescriptor(
  name='WaterfallMode',
  full_name='notification_hub.NotificationTask.WaterfallMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTO', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OVERRIDE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=585,
  serialized_end=624,
)
_sym_db.RegisterEnumDescriptor(_NOTIFICATIONTASK_WATERFALLMODE)

_NOTIFICATIONTASK_PLATFORM = _descriptor.EnumDescriptor(
  name='Platform',
  full_name='notification_hub.NotificationTask.Platform',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AASAANJOBS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OLXPEOPLE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=626,
  serialized_end=667,
)
_sym_db.RegisterEnumDescriptor(_NOTIFICATIONTASK_PLATFORM)

_PUSH_CLIENTPLATFORM = _descriptor.EnumDescriptor(
  name='ClientPlatform',
  full_name='notification_hub.Push.ClientPlatform',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ANDROID', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IOS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEB', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1775,
  serialized_end=1822,
)
_sym_db.RegisterEnumDescriptor(_PUSH_CLIENTPLATFORM)


_NOTIFICATIONTASK = _descriptor.Descriptor(
  name='NotificationTask',
  full_name='notification_hub.NotificationTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='notification_hub.NotificationTask.ID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='notification_hub.NotificationTask.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='messageType', full_name='notification_hub.NotificationTask.messageType', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='email', full_name='notification_hub.NotificationTask.email', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sms', full_name='notification_hub.NotificationTask.sms', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='whatsapp', full_name='notification_hub.NotificationTask.whatsapp', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='push', full_name='notification_hub.NotificationTask.push', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sentByID', full_name='notification_hub.NotificationTask.sentByID', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client', full_name='notification_hub.NotificationTask.client', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='waterfallType', full_name='notification_hub.NotificationTask.waterfallType', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='triggeredOn', full_name='notification_hub.NotificationTask.triggeredOn', index=10,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='platform', full_name='notification_hub.NotificationTask.platform', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventID', full_name='notification_hub.NotificationTask.eventID', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _NOTIFICATIONTASK_MESSAGETYPE,
    _NOTIFICATIONTASK_WATERFALLMODE,
    _NOTIFICATIONTASK_PLATFORM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44,
  serialized_end=667,
)


_WATERFALL = _descriptor.Descriptor(
  name='Waterfall',
  full_name='notification_hub.Waterfall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='priority', full_name='notification_hub.Waterfall.priority', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offsetTime', full_name='notification_hub.Waterfall.offsetTime', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=669,
  serialized_end=718,
)


_SMS = _descriptor.Descriptor(
  name='SMS',
  full_name='notification_hub.SMS',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='template', full_name='notification_hub.SMS.template', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mobile', full_name='notification_hub.SMS.mobile', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='context', full_name='notification_hub.SMS.context', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='waterfallConfig', full_name='notification_hub.SMS.waterfallConfig', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='notification_hub.SMS.expiry', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userID', full_name='notification_hub.SMS.userID', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=721,
  serialized_end=863,
)


_WHATSAPP = _descriptor.Descriptor(
  name='Whatsapp',
  full_name='notification_hub.Whatsapp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='template', full_name='notification_hub.Whatsapp.template', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mobile', full_name='notification_hub.Whatsapp.mobile', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='context', full_name='notification_hub.Whatsapp.context', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='waterfallConfig', full_name='notification_hub.Whatsapp.waterfallConfig', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='notification_hub.Whatsapp.expiry', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userID', full_name='notification_hub.Whatsapp.userID', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=866,
  serialized_end=1013,
)


_EMAILRECIPIENT = _descriptor.Descriptor(
  name='EmailRecipient',
  full_name='notification_hub.EmailRecipient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='email', full_name='notification_hub.EmailRecipient.email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='notification_hub.EmailRecipient.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userID', full_name='notification_hub.EmailRecipient.userID', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1015,
  serialized_end=1076,
)


_EMAILATTACHMENT = _descriptor.Descriptor(
  name='EmailAttachment',
  full_name='notification_hub.EmailAttachment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='notification_hub.EmailAttachment.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='notification_hub.EmailAttachment.url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1078,
  serialized_end=1126,
)


_EMAIL = _descriptor.Descriptor(
  name='Email',
  full_name='notification_hub.Email',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='template', full_name='notification_hub.Email.template', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='toRecipients', full_name='notification_hub.Email.toRecipients', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='context', full_name='notification_hub.Email.context', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subject', full_name='notification_hub.Email.subject', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender', full_name='notification_hub.Email.sender', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replyTo', full_name='notification_hub.Email.replyTo', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ccRecipients', full_name='notification_hub.Email.ccRecipients', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attachments', full_name='notification_hub.Email.attachments', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='waterfallConfig', full_name='notification_hub.Email.waterfallConfig', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='notification_hub.Email.expiry', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1129,
  serialized_end=1527,
)


_PUSH = _descriptor.Descriptor(
  name='Push',
  full_name='notification_hub.Push',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='template', full_name='notification_hub.Push.template', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='notification_hub.Push.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='context', full_name='notification_hub.Push.context', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='waterfallConfig', full_name='notification_hub.Push.waterfallConfig', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='notification_hub.Push.expiry', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userID', full_name='notification_hub.Push.userID', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extraPayload', full_name='notification_hub.Push.extraPayload', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clientPlatform', full_name='notification_hub.Push.clientPlatform', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dryRun', full_name='notification_hub.Push.dryRun', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PUSH_CLIENTPLATFORM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1530,
  serialized_end=1822,
)

_NOTIFICATIONTASK.fields_by_name['messageType'].enum_type = _NOTIFICATIONTASK_MESSAGETYPE
_NOTIFICATIONTASK.fields_by_name['email'].message_type = _EMAIL
_NOTIFICATIONTASK.fields_by_name['sms'].message_type = _SMS
_NOTIFICATIONTASK.fields_by_name['whatsapp'].message_type = _WHATSAPP
_NOTIFICATIONTASK.fields_by_name['push'].message_type = _PUSH
_NOTIFICATIONTASK.fields_by_name['waterfallType'].enum_type = _NOTIFICATIONTASK_WATERFALLMODE
_NOTIFICATIONTASK.fields_by_name['platform'].enum_type = _NOTIFICATIONTASK_PLATFORM
_NOTIFICATIONTASK_MESSAGETYPE.containing_type = _NOTIFICATIONTASK
_NOTIFICATIONTASK_WATERFALLMODE.containing_type = _NOTIFICATIONTASK
_NOTIFICATIONTASK_PLATFORM.containing_type = _NOTIFICATIONTASK
_SMS.fields_by_name['waterfallConfig'].message_type = _WATERFALL
_WHATSAPP.fields_by_name['waterfallConfig'].message_type = _WATERFALL
_EMAIL.fields_by_name['toRecipients'].message_type = _EMAILRECIPIENT
_EMAIL.fields_by_name['sender'].message_type = _EMAILRECIPIENT
_EMAIL.fields_by_name['replyTo'].message_type = _EMAILRECIPIENT
_EMAIL.fields_by_name['ccRecipients'].message_type = _EMAILRECIPIENT
_EMAIL.fields_by_name['attachments'].message_type = _EMAILATTACHMENT
_EMAIL.fields_by_name['waterfallConfig'].message_type = _WATERFALL
_PUSH.fields_by_name['waterfallConfig'].message_type = _WATERFALL
_PUSH.fields_by_name['clientPlatform'].enum_type = _PUSH_CLIENTPLATFORM
_PUSH_CLIENTPLATFORM.containing_type = _PUSH
DESCRIPTOR.message_types_by_name['NotificationTask'] = _NOTIFICATIONTASK
DESCRIPTOR.message_types_by_name['Waterfall'] = _WATERFALL
DESCRIPTOR.message_types_by_name['SMS'] = _SMS
DESCRIPTOR.message_types_by_name['Whatsapp'] = _WHATSAPP
DESCRIPTOR.message_types_by_name['EmailRecipient'] = _EMAILRECIPIENT
DESCRIPTOR.message_types_by_name['EmailAttachment'] = _EMAILATTACHMENT
DESCRIPTOR.message_types_by_name['Email'] = _EMAIL
DESCRIPTOR.message_types_by_name['Push'] = _PUSH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NotificationTask = _reflection.GeneratedProtocolMessageType('NotificationTask', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONTASK,
  '__module__' : 'notificationHub_pb2'
  # @@protoc_insertion_point(class_scope:notification_hub.NotificationTask)
  })
_sym_db.RegisterMessage(NotificationTask)

Waterfall = _reflection.GeneratedProtocolMessageType('Waterfall', (_message.Message,), {
  'DESCRIPTOR' : _WATERFALL,
  '__module__' : 'notificationHub_pb2'
  # @@protoc_insertion_point(class_scope:notification_hub.Waterfall)
  })
_sym_db.RegisterMessage(Waterfall)

SMS = _reflection.GeneratedProtocolMessageType('SMS', (_message.Message,), {
  'DESCRIPTOR' : _SMS,
  '__module__' : 'notificationHub_pb2'
  # @@protoc_insertion_point(class_scope:notification_hub.SMS)
  })
_sym_db.RegisterMessage(SMS)

Whatsapp = _reflection.GeneratedProtocolMessageType('Whatsapp', (_message.Message,), {
  'DESCRIPTOR' : _WHATSAPP,
  '__module__' : 'notificationHub_pb2'
  # @@protoc_insertion_point(class_scope:notification_hub.Whatsapp)
  })
_sym_db.RegisterMessage(Whatsapp)

EmailRecipient = _reflection.GeneratedProtocolMessageType('EmailRecipient', (_message.Message,), {
  'DESCRIPTOR' : _EMAILRECIPIENT,
  '__module__' : 'notificationHub_pb2'
  # @@protoc_insertion_point(class_scope:notification_hub.EmailRecipient)
  })
_sym_db.RegisterMessage(EmailRecipient)

EmailAttachment = _reflection.GeneratedProtocolMessageType('EmailAttachment', (_message.Message,), {
  'DESCRIPTOR' : _EMAILATTACHMENT,
  '__module__' : 'notificationHub_pb2'
  # @@protoc_insertion_point(class_scope:notification_hub.EmailAttachment)
  })
_sym_db.RegisterMessage(EmailAttachment)

Email = _reflection.GeneratedProtocolMessageType('Email', (_message.Message,), {
  'DESCRIPTOR' : _EMAIL,
  '__module__' : 'notificationHub_pb2'
  # @@protoc_insertion_point(class_scope:notification_hub.Email)
  })
_sym_db.RegisterMessage(Email)

Push = _reflection.GeneratedProtocolMessageType('Push', (_message.Message,), {
  'DESCRIPTOR' : _PUSH,
  '__module__' : 'notificationHub_pb2'
  # @@protoc_insertion_point(class_scope:notification_hub.Push)
  })
_sym_db.RegisterMessage(Push)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import importlib
import os
from configparser import (ConfigParser, NoOptionError, NoSectionError,
                          ParsingError)
from os import path

import boto3

from notificationhub_sdk.base import ImproperlyConfigured
from notificationhub_sdk.common import MessageType

TOKEN_PATH = "/var/run/secrets/eks.amazonaws.com/serviceaccount/token"

class SQSProducer:
    """
    Used for pushing the messages to SQS
    """
    setting_keys = (
        ('access_key_id', 'NOTIFICATION_HUB_SQS_ACCESS_KEY_ID'),
        ('secret_access_key', 'NOTIFICATION_HUB_SQS_SECRET_ACCESS_KEY'),
        ('region', 'NOTIFICATION_HUB_SQS_REGION'),
        ('queue_name', 'NOTIFICATION_HUB_SQS_QUEUE_NAME'),  # transactional queue name
        ('marketing_queue_name', 'NOTIFICATION_HUB_MARKETING_SQS_QUEUE_NAME'), # marketing queue name
        ('otp_queue_name', 'NOTIFICATION_HUB_OTP_SQS_QUEUE_NAME'), # otp queue name
        ('eks_role_arn', 'EKS_ROLE_ARN'),  # for EKS role-based access; to push msgs to SQS
    )

    def __init__(self, **kwargs):
        # Retrieve Settings
        self.access_key_id = self._get_setting(*self.setting_keys[0], **kwargs)
        self.secret_access_key = self._get_setting(*self.setting_keys[1], **kwargs)
        self.region = self._get_setting(*self.setting_keys[2], **kwargs)
        self.queue_name = self._get_setting(*self.setting_keys[3], **kwargs)
        self.marketing_queue_name = self._get_setting(*self.setting_keys[4], **kwargs)
        self.otp_queue_name = self._get_setting(*self.setting_keys[5], **kwargs)
        self.eks_role_arn = self._get_setting(*self.setting_keys[6], **kwargs)

        # check whether at least one queue is set or not
        if (self.queue_name is None or self.queue_name == "") and \
            (self.marketing_queue_name is None or self.marketing_queue_name == "") and \
                (self.otp_queue_name is None or self.otp_queue_name == ""):
            raise ImproperlyConfigured('At least one queue should be set.')

        self._session = None
        self._queue = None
        self.init_sqs_session(kwargs.get('endpoint_url'))


    def _get_setting(self, kw_name, env_name, **kwargs):
        """
        To read the setting from django settings or env
        :param kw_name: setting value to be retrived
        :param env_name: kw
        :return: Setting Value retrieved from the django setting or env
        """
        value = ""
        if kwargs.get(kw_name):
            return kwargs[kw_name]
        value = self.__get_from_django_settings(env_name)
        # If not found in Django settings, retrieve from environment variables
        if not value:
            value = os.getenv(env_name)

        return value

    @staticmethod
    def __get_from_django_settings(name):
        """
        If the Django project is initiated, then retrieves the settings
        from Django settings
        :param name: Setting Name
        :return: Setting Value
        """
        try:
            module = importlib.import_module('django.conf')
            settings = getattr(module, 'settings')
            return getattr(settings, name, None)
        except ImportError:
            return None

    def init_sqs_session(self, endpoint_url=None):
        """
        creates aws session based on different criteria
        - Access key and secret key given in the settings
        - EC2: based on the assumption that the role is given to the EC2 instance
        - EKS-role based access: eks_role_arn is taken into consideration
        - Local settings: read from the local ~/.aws/credentials path
        """
        if endpoint_url:
            client_kwargs['endpoint_url'] = endpoint_url

        session_created = False
        
        # Access key and secret key given in the settings
        if self.access_key_id and self.secret_access_key:
            client_kwargs = {
                'service_name': "sqs",
                'aws_access_key_id': self.access_key_id,
                'aws_secret_access_key': self.secret_access_key,
                'region_name': self.region
            }
            self._session = boto3.resource(**client_kwargs)
            if self._session is not None:
                session_created = True

        # EC2: based on the assumption that the role is given to the EC2 instance
        if self._session is None and not session_created:
            client_kwargs = {
                'service_name': "sqs",
                'region_name': self.region
            }
            self._session = boto3.resource(**client_kwargs)
            if self._session is not None:
                session_created = True

        # eks role-based access
        if self.eks_role_arn and self.eks_role_arn != "":
            # check whether the given information has the account number or not
            aws_client = boto3.client('sts')
            if aws_client == None or aws_client == "":
                raise ImproperlyConfigured('Issue while connecting to SQS region `{}`'.format(self.region))

            try:
                if not path.exists(TOKEN_PATH):
                    raise ImproperlyConfigured('Token not present in pod. Check token at `{}`'.format(TOKEN_PATH))
                with open(TOKEN_PATH, 'r') as file:
                    access_details = file.read()
                response = aws_client.assume_role_with_web_identity(
                    RoleArn=self.eks_role_arn,
                    RoleSessionName='string',
                    WebIdentityToken=access_details,
                )
                if not response:
                    raise ImproperlyConfigured('Issue with token in pod. Check token at `{0}` with {1} '.format(TOKEN_PATH, self.eks_role_arn))
                session_created = True
            except ImportError:
                raise ImproperlyConfigured('Token not present in pod. Check token at `{0}` with {1} '.format(TOKEN_PATH, self.eks_role_arn))
        
        # local development
        if self._session is None and not session_created:
            self._session = boto3.resource("sqs")
            if self._session is not None:
                session_created = True

        # check whether session is created after all possible options
        if not session_created:
            raise ImproperlyConfigured('AWS session is not created due to improper setting provided in region `{}`'.format(self.region))

    def send_message(self, message_body: str, message_type: MessageType) -> str:
        """
        Sends a message to Amazon SQS
        :param message_body: The message to be pushed to queue
        :param message_type: The type of message to be processed. This is used to identify the queue
        :returns The MessageId returned by AWS
        :raises ConnectionError if failure in sending occurs
        """
        queue_name = self.queue_name
        if message_type == MessageType.MARKETING:
            queue_name = self.marketing_queue_name
        elif message_type == MessageType.TRANSACTIONAL:
            queue_name = self.queue_name
        elif message_type == MessageType.OTP:
            queue_name = self.otp_queue_name

        self._queue = self._session.get_queue_by_name(QueueName=queue_name)
        res = self._queue.send_message(QueueUrl=self._queue.url, MessageBody=str(message_body))
        status_code = res.get('ResponseMetadata').get('HTTPStatusCode')
        if status_code / 100 != 2:
            raise ConnectionError('Failed to send message to Hub Queue')
        return res['MessageId']



import json
from typing import List

from ..base import get_expiry, validate_email, validate_template, validate_attachment_url
from ..common import Waterfall, Platform
from ..proto import notification_hub_pb2 as pb


class EmailRecipient:

    def __init__(self, email: str, name: str = "", user_id: str = ""):
        """
        Parameters:
            email (str): Email ID
            name (str, optional): The name of the person or company
            user_id (str, optional): The User ID to whom the notification is being sent
        """
        self._email_recipient = pb.EmailRecipient()
        validate_email(email)
        self._email_recipient.email = email
        self._email_recipient.name = name
        self._email_recipient.userID = user_id if user_id else ''

    @property
    def proto(self) -> pb.EmailRecipient:
        return self._email_recipient


class EmailAttachment:

    def __init__(self, file_name: str, url: str):
        """
        Parameters:
            file_name (str): The filename of the attachment
            url (str): Accessible URL of the file
        """
        validate_attachment_url(url)
        self._email_attachment = pb.EmailAttachment()
        self._email_attachment.filename = file_name
        self._email_attachment.url = url

    @property
    def proto(self) -> pb.EmailAttachment:
        return self._email_attachment


class Email:
    _default_expiry_offset = 7    # 7 Days

    def __init__(
            self,
            send_to: List[EmailRecipient],
            template: str,
            subject: str,
            context: dict = None,
            sender: EmailRecipient = None,
            reply_to: EmailRecipient = None,
            cc: List[EmailRecipient] = None,
            attachments: List[EmailAttachment] = None,
            waterfall_config: Waterfall = None,
            expiry: int = None,
            platform: Platform = Platform.Aasaanjobs
    ):
        """
        Parameters:
            send_to (EmailRecipient[]): An array of recipients. Each object within this array may contain the name,
                but must always contain the email, of a recipient. (min: 1, max: 1000)
            template (str): The Email base template URL which will get rendered with the variable data provided.
            subject (str): The subject of your email. Char length requirements, according to the RFC -
                http://stackoverflow.com/questions/1592291/what-is-the-email-subject-length-limit#answer-1592310
            context (dict, optional): A dictionary of variable data to be rendered in the template
            sender (EmailRecipient, optional): The name and email of the person who is sending the mail
            reply_to (EmailRecipient, optional): The name and email of the person to whom recipients can reply to
            cc (EmailRecipient[], optional): An array of recipients who will receive a copy of your email. Each object
                within this array may contain the name, but must always contain the email, of a recipient.
            attachments (EmailAttachment[], optional): An array of objects in which you can specify any attachments
                you want to include.
            waterfall_config (Waterfall, optional): The configuration to be used by Hub priority engine to schedule
                this channel
            expiry (int, optional): The Epoch timestamp at which this notification task should expire if still not sent
        """
        self._email = pb.Email()
        self.__set_recipients(send_to)

        validate_template(template)
        self._email.template = template

        self._email.subject = subject
        self.platform = platform
        self._email.context = json.dumps(context) if context else '{}'
        self.__set_attachments(attachments)
        self._email.sender.CopyFrom(self.__set_sender(sender))
        self._email.replyTo.CopyFrom(self.__set_reply_to(reply_to))
        self.__set_cc(cc)
        self.__set_waterfall(waterfall_config)
        self._email.expiry = expiry if expiry else get_expiry(self._default_expiry_offset)

    def __set_recipients(self, send_to: List[EmailRecipient]):
        for _ in send_to:
            self._email.toRecipients.append(_.proto)

    def __set_cc(self, cc: List[EmailRecipient]):
        if not cc:
            cc = []
        for _ in cc:
            self._email.ccRecipients.append(_.proto)

    def __set_attachments(self, attachments: List[EmailAttachment]):
        if not attachments:
            attachments = []
        for _ in attachments:
            self._email.attachments.append(_.proto)

    def __set_sender(self, sender: EmailRecipient = None):
        if sender:
            return sender.proto
        if self.platform == Platform.Aasaanjobs:
            return EmailRecipient('noreply@aasaanjobs.com', 'Aasaanjobs').proto
        else:
            return EmailRecipient('noreply@olxpeople.com', 'OLX People').proto

    def __set_reply_to(self, reply_to: EmailRecipient = None):
        if reply_to:
            return reply_to.proto
        if self.platform == Platform.Aasaanjobs:
            return EmailRecipient('support@aasaanjobs.com', 'Aasaanjobs').proto
        else:
            return EmailRecipient('support@olxpeople.com', 'OLX People').proto

    def __set_waterfall(self, value: Waterfall = None):
        if not value:
            value = Waterfall()
        self._email.waterfallConfig.CopyFrom(value.proto)

    @property
    def proto(self) -> pb.Email:
        return self._email
